# Copyright (c) 2007 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id: interfaces.py 5470 2007-12-07 15:52:23Z zagy $

import zope.interface
import zope.publisher.interfaces.browser
import zope.schema


class IFieldGroup(zope.interface.Interface):

    title = zope.schema.TextLine(title=u"Widget Group Title")

    css_class = zope.schema.TextLine(
        title=u"CSS class to apply to the group")

    widgets = zope.schema.List(
        title=u"Widges of this group",
        description=u"Will be filled by form")

    def get_field_names():
        "Return list of field names."


class IRemainingFields(IFieldGroup):
    """Marker interface for a fieldgroup which contains all remaining fields.

    Remaining fields are fields which are not noted in any other field group.

    """

    def get_field_names():
        """Returns None."""


class IGroupedForm(zope.interface.Interface):

    field_groups = zope.schema.List(
        title=u"Field groups to display",
        value_type=zope.schema.Object(IFieldGroup))


class IJSValidationLayer(zope.publisher.interfaces.browser.IBrowserRequest):
    """Layer for default javascript validation functions."""


class IJSValidator(zope.interface.Interface):
    """A javascript validation adapter.

    XXX

    """



# Copyright (c) 2007 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id: __init__.py 5091 2007-08-22 14:25:17Z zagy $

#namespace package boilerplate
try:
    __import__('pkg_resources').declare_namespace(__name__)
except ImportError, e:
    from pkgutil import extend_path
    __path__ = extend_path(__path__, __name__)




# -*- coding: latin-1 -*-
# Copyright (c) 2007 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id: pagelet.py 5231 2007-09-27 13:56:48Z sweh $

"""Pagelet support for z3c.form forms."""

import z3c.form.form
import z3c.pagelet.browser
import z3c.pagelet.interfaces
import zope.interface
import z3c.template.interfaces
import zope.component

class Form(z3c.pagelet.browser.BrowserPagelet, z3c.form.form.Form):
        """Pagelet support for z3c.form.form.Form"""
        zope.interface.implements(z3c.pagelet.interfaces.IPageletForm)

        update = z3c.form.form.Form.update

class AddForm(z3c.pagelet.browser.BrowserPagelet, z3c.form.form.AddForm):
        """Pagelet support for z3c.form.form.AddForm"""
        zope.interface.implements(z3c.pagelet.interfaces.IPageletAddForm)

        update = z3c.form.form.AddForm.update

class EditForm(z3c.pagelet.browser.BrowserPagelet, z3c.form.form.EditForm):
        """Pagelet support for z3c.form.form.EditForm"""
        zope.interface.implements(z3c.pagelet.interfaces.IPageletEditForm)

        update = z3c.form.form.EditForm.update



# -*- coding: latin-1 -*-
# Copyright (c) 2007 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id$
"""Tools for schema field constraints."""


def _all(list):
    """Emulates Python 2.5's all() function."""
    return bool(len([x for x in list if x]))


def all(*constraints):
    return lambda value:_all([c(value) for c in constraints])



# Copyright (c) 2007 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id: setup.py 5486 2007-12-19 10:03:02Z zagy $

import os.path

from setuptools import setup, find_packages


setup(
    name = 'gocept.form',
    version = "0.7.1",
    author = "Christian Zagrodnick",
    author_email = "cz@gocept.com",
    description = "Extensions for zope.formlib",
    long_description = file(os.path.join(os.path.dirname(__file__),
                                         'README.txt')).read(),
    license = "ZPL 2.1",
    url='http://pypi.python.org/pypi/gocept.form',

    packages = find_packages('src'),
    package_dir = {'': 'src'},

    include_package_data = True,
    zip_safe = False,

    namespace_packages = ['gocept'],
    install_requires = [
        'setuptools',
        'gocept.mochikit>=1.3.1',
        'zope.interface',
        'zope.component',
        'zope.contentprovider',
        'zope.viewlet',
        'zc.resourcelibrary',
    ],
    extras_require = dict(
        test=['zope.testing',
              'zope.testbrowser',
              'zope.app.testing',
              'zope.app.zcmlfiles',
             ],
        formlib=['zope.formlib',
                 'zope.app.pagetemplate',
                ],
        z3cform=['z3c.form',
                 'z3c.pagelet'
                ])
    )
